==> haskell-findbin-0.0.5-20-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-findbin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 FindBin
version:              0.0.5
visibility:           public
id:                   FindBin-0.0.5-J08yvTLNGNg5dC092Jxdci
key:                  FindBin-0.0.5-J08yvTLNGNg5dC092Jxdci
license:              BSD-3-Clause
copyright:            2008-2011 Audrey Tang
maintainer:           Audrey Tang <audreyt@audreyt.org>
author:               Audrey Tang <audreyt@audreyt.org>
stability:            Stable
homepage:             https://github.com/audreyt/findbin
synopsis:             Locate directory of original program
description:
    This module locates the full directory to the running program,
    to allow the use of paths relative to it.
    FindBin supports invocation of Haskell programs via "ghci",
    via "runhaskell/runghc", as well as compiled as an executable.

category:             System
abi:                  10bc4601865b2a4e4cdde913b3249da0
exposed:              True
exposed-modules:      System.Environment.FindBin
import-dirs:          /usr/lib/ghc-9.2.8/site-local/FindBin-0.0.5
library-dirs:         /usr/lib/ghc-9.2.8/site-local/FindBin-0.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-findbin
hs-libraries:         HSFindBin-0.0.5-J08yvTLNGNg5dC092Jxdci
depends:              base-4.16.4.0 directory-1.3.6.2 filepath-1.4.2.2
haddock-interfaces:   /usr/share/doc/haskell-findbin/html/FindBin.haddock
haddock-html:         /usr/share/doc/haskell-findbin/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-findbin-0.0.5-21-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-findbin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 FindBin
version:              0.0.5
visibility:           public
id:                   FindBin-0.0.5-Ch6axMNO9p8ChWTyJ3svia
key:                  FindBin-0.0.5-Ch6axMNO9p8ChWTyJ3svia
license:              BSD-3-Clause
copyright:            2008-2011 Audrey Tang
maintainer:           Audrey Tang <audreyt@audreyt.org>
author:               Audrey Tang <audreyt@audreyt.org>
stability:            Stable
homepage:             https://github.com/audreyt/findbin
synopsis:             Locate directory of original program
description:
    This module locates the full directory to the running program,
    to allow the use of paths relative to it.
    FindBin supports invocation of Haskell programs via "ghci",
    via "runhaskell/runghc", as well as compiled as an executable.

category:             System
abi:                  2c100113a7aab30c21bb73d5a42e6e73
exposed:              True
exposed-modules:      System.Environment.FindBin
import-dirs:          /usr/lib/ghc-9.4.8/site-local/FindBin-0.0.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/FindBin-0.0.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/FindBin-0.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-findbin
hs-libraries:         HSFindBin-0.0.5-Ch6axMNO9p8ChWTyJ3svia
depends:              base-4.17.2.1 directory-1.3.7.1 filepath-1.4.2.2
haddock-interfaces:   /usr/share/doc/haskell-findbin/html/FindBin.haddock
haddock-html:         /usr/share/doc/haskell-findbin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
